# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


class Currency (DateModel, UserModel, StatusModel, OrderedModel):
    """
    Stores currencies
    """
    code = models.CharField(
        unique=True,
        max_length=15,
        verbose_name=_('Code'),
    )
    name = models.CharField(
        unique=True,
        max_length=100,
        verbose_name=_('Name'),
    )
    slug = models.SlugField(
        db_index=True,
        max_length=100,
        verbose_name=_("Slug"),
        help_text=_("Used for URLs, auto-generated from name if blank"),
    )
    symbol = models.CharField(
        max_length=3,
        verbose_name=_('Symbol'),
    )

    class Meta:
        verbose_name = _('Currency')
        verbose_name_plural = _('Currencies')
        ordering = ('ordering', 'code')
        permissions = (
            ("view_currency", "Can view currency"),
        )

    def __unicode__(self):
        return u"%s" % self.name
